testa

package
v0.0.0-...-1e4cd2d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the testa type in the database.
	Label = "testa"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldInt4 holds the string denoting the int4 field in the database.
	FieldInt4 = "int4"
	// FieldInt8 holds the string denoting the int8 field in the database.
	FieldInt8 = "int8"
	// FieldFloat4 holds the string denoting the float4 field in the database.
	FieldFloat4 = "float4"
	// FieldFloat8 holds the string denoting the float8 field in the database.
	FieldFloat8 = "float8"
	// FieldBool holds the string denoting the bool field in the database.
	FieldBool = "bool"
	// FieldText holds the string denoting the text field in the database.
	FieldText = "text"
	// FieldTime holds the string denoting the time field in the database.
	FieldTime = "time"
	// EdgeTestBs holds the string denoting the test_bs edge name in mutations.
	EdgeTestBs = "test_bs"
	// Table holds the table name of the testa in the database.
	Table = "test_a"
	// TestBsTable is the table that holds the test_bs relation/edge.
	TestBsTable = "test_b"
	// TestBsInverseTable is the table name for the TestB entity.
	// It exists in this package in order to avoid circular dependency with the "testb" package.
	TestBsInverseTable = "test_b"
	// TestBsColumn is the table column denoting the test_bs relation/edge.
	TestBsColumn = "a_id"
)

Variables

Columns holds all SQL columns for testa fields.

Functions

func And

func And(predicates ...predicate.TestA) predicate.TestA

And groups predicates with the AND operator between them.

func Bool

func Bool(v bool) predicate.TestA

Bool applies equality check predicate on the "bool" field. It's identical to BoolEQ.

func BoolEQ

func BoolEQ(v bool) predicate.TestA

BoolEQ applies the EQ predicate on the "bool" field.

func BoolNEQ

func BoolNEQ(v bool) predicate.TestA

BoolNEQ applies the NEQ predicate on the "bool" field.

func Float4

func Float4(v float32) predicate.TestA

Float4 applies equality check predicate on the "float4" field. It's identical to Float4EQ.

func Float4EQ

func Float4EQ(v float32) predicate.TestA

Float4EQ applies the EQ predicate on the "float4" field.

func Float4GT

func Float4GT(v float32) predicate.TestA

Float4GT applies the GT predicate on the "float4" field.

func Float4GTE

func Float4GTE(v float32) predicate.TestA

Float4GTE applies the GTE predicate on the "float4" field.

func Float4In

func Float4In(vs ...float32) predicate.TestA

Float4In applies the In predicate on the "float4" field.

func Float4LT

func Float4LT(v float32) predicate.TestA

Float4LT applies the LT predicate on the "float4" field.

func Float4LTE

func Float4LTE(v float32) predicate.TestA

Float4LTE applies the LTE predicate on the "float4" field.

func Float4NEQ

func Float4NEQ(v float32) predicate.TestA

Float4NEQ applies the NEQ predicate on the "float4" field.

func Float4NotIn

func Float4NotIn(vs ...float32) predicate.TestA

Float4NotIn applies the NotIn predicate on the "float4" field.

func Float8

func Float8(v float64) predicate.TestA

Float8 applies equality check predicate on the "float8" field. It's identical to Float8EQ.

func Float8EQ

func Float8EQ(v float64) predicate.TestA

Float8EQ applies the EQ predicate on the "float8" field.

func Float8GT

func Float8GT(v float64) predicate.TestA

Float8GT applies the GT predicate on the "float8" field.

func Float8GTE

func Float8GTE(v float64) predicate.TestA

Float8GTE applies the GTE predicate on the "float8" field.

func Float8In

func Float8In(vs ...float64) predicate.TestA

Float8In applies the In predicate on the "float8" field.

func Float8LT

func Float8LT(v float64) predicate.TestA

Float8LT applies the LT predicate on the "float8" field.

func Float8LTE

func Float8LTE(v float64) predicate.TestA

Float8LTE applies the LTE predicate on the "float8" field.

func Float8NEQ

func Float8NEQ(v float64) predicate.TestA

Float8NEQ applies the NEQ predicate on the "float8" field.

func Float8NotIn

func Float8NotIn(vs ...float64) predicate.TestA

Float8NotIn applies the NotIn predicate on the "float8" field.

func HasTestBs

func HasTestBs() predicate.TestA

HasTestBs applies the HasEdge predicate on the "test_bs" edge.

func HasTestBsWith

func HasTestBsWith(preds ...predicate.TestB) predicate.TestA

HasTestBsWith applies the HasEdge predicate on the "test_bs" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.TestA

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.TestA

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.TestA

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.TestA

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.TestA

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.TestA

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.TestA

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.TestA

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.TestA

IDNotIn applies the NotIn predicate on the ID field.

func Int4

func Int4(v int32) predicate.TestA

Int4 applies equality check predicate on the "int4" field. It's identical to Int4EQ.

func Int4EQ

func Int4EQ(v int32) predicate.TestA

Int4EQ applies the EQ predicate on the "int4" field.

func Int4GT

func Int4GT(v int32) predicate.TestA

Int4GT applies the GT predicate on the "int4" field.

func Int4GTE

func Int4GTE(v int32) predicate.TestA

Int4GTE applies the GTE predicate on the "int4" field.

func Int4In

func Int4In(vs ...int32) predicate.TestA

Int4In applies the In predicate on the "int4" field.

func Int4LT

func Int4LT(v int32) predicate.TestA

Int4LT applies the LT predicate on the "int4" field.

func Int4LTE

func Int4LTE(v int32) predicate.TestA

Int4LTE applies the LTE predicate on the "int4" field.

func Int4NEQ

func Int4NEQ(v int32) predicate.TestA

Int4NEQ applies the NEQ predicate on the "int4" field.

func Int4NotIn

func Int4NotIn(vs ...int32) predicate.TestA

Int4NotIn applies the NotIn predicate on the "int4" field.

func Int8

func Int8(v int) predicate.TestA

Int8 applies equality check predicate on the "int8" field. It's identical to Int8EQ.

func Int8EQ

func Int8EQ(v int) predicate.TestA

Int8EQ applies the EQ predicate on the "int8" field.

func Int8GT

func Int8GT(v int) predicate.TestA

Int8GT applies the GT predicate on the "int8" field.

func Int8GTE

func Int8GTE(v int) predicate.TestA

Int8GTE applies the GTE predicate on the "int8" field.

func Int8In

func Int8In(vs ...int) predicate.TestA

Int8In applies the In predicate on the "int8" field.

func Int8LT

func Int8LT(v int) predicate.TestA

Int8LT applies the LT predicate on the "int8" field.

func Int8LTE

func Int8LTE(v int) predicate.TestA

Int8LTE applies the LTE predicate on the "int8" field.

func Int8NEQ

func Int8NEQ(v int) predicate.TestA

Int8NEQ applies the NEQ predicate on the "int8" field.

func Int8NotIn

func Int8NotIn(vs ...int) predicate.TestA

Int8NotIn applies the NotIn predicate on the "int8" field.

func Name

func Name(v string) predicate.TestA

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.TestA

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.TestA

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.TestA

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.TestA

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.TestA

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.TestA

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.TestA

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.TestA

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.TestA

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.TestA

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.TestA

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.TestA

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.TestA

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.TestA) predicate.TestA

Or groups predicates with the OR operator between them.

func Text

func Text(v string) predicate.TestA

Text applies equality check predicate on the "text" field. It's identical to TextEQ.

func TextContains

func TextContains(v string) predicate.TestA

TextContains applies the Contains predicate on the "text" field.

func TextContainsFold

func TextContainsFold(v string) predicate.TestA

TextContainsFold applies the ContainsFold predicate on the "text" field.

func TextEQ

func TextEQ(v string) predicate.TestA

TextEQ applies the EQ predicate on the "text" field.

func TextEqualFold

func TextEqualFold(v string) predicate.TestA

TextEqualFold applies the EqualFold predicate on the "text" field.

func TextGT

func TextGT(v string) predicate.TestA

TextGT applies the GT predicate on the "text" field.

func TextGTE

func TextGTE(v string) predicate.TestA

TextGTE applies the GTE predicate on the "text" field.

func TextHasPrefix

func TextHasPrefix(v string) predicate.TestA

TextHasPrefix applies the HasPrefix predicate on the "text" field.

func TextHasSuffix

func TextHasSuffix(v string) predicate.TestA

TextHasSuffix applies the HasSuffix predicate on the "text" field.

func TextIn

func TextIn(vs ...string) predicate.TestA

TextIn applies the In predicate on the "text" field.

func TextLT

func TextLT(v string) predicate.TestA

TextLT applies the LT predicate on the "text" field.

func TextLTE

func TextLTE(v string) predicate.TestA

TextLTE applies the LTE predicate on the "text" field.

func TextNEQ

func TextNEQ(v string) predicate.TestA

TextNEQ applies the NEQ predicate on the "text" field.

func TextNotIn

func TextNotIn(vs ...string) predicate.TestA

TextNotIn applies the NotIn predicate on the "text" field.

func Time

func Time(v time.Time) predicate.TestA

Time applies equality check predicate on the "time" field. It's identical to TimeEQ.

func TimeEQ

func TimeEQ(v time.Time) predicate.TestA

TimeEQ applies the EQ predicate on the "time" field.

func TimeGT

func TimeGT(v time.Time) predicate.TestA

TimeGT applies the GT predicate on the "time" field.

func TimeGTE

func TimeGTE(v time.Time) predicate.TestA

TimeGTE applies the GTE predicate on the "time" field.

func TimeIn

func TimeIn(vs ...time.Time) predicate.TestA

TimeIn applies the In predicate on the "time" field.

func TimeLT

func TimeLT(v time.Time) predicate.TestA

TimeLT applies the LT predicate on the "time" field.

func TimeLTE

func TimeLTE(v time.Time) predicate.TestA

TimeLTE applies the LTE predicate on the "time" field.

func TimeNEQ

func TimeNEQ(v time.Time) predicate.TestA

TimeNEQ applies the NEQ predicate on the "time" field.

func TimeNotIn

func TimeNotIn(vs ...time.Time) predicate.TestA

TimeNotIn applies the NotIn predicate on the "time" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the TestA queries.

func ByBool

func ByBool(opts ...sql.OrderTermOption) OrderOption

ByBool orders the results by the bool field.

func ByFloat4

func ByFloat4(opts ...sql.OrderTermOption) OrderOption

ByFloat4 orders the results by the float4 field.

func ByFloat8

func ByFloat8(opts ...sql.OrderTermOption) OrderOption

ByFloat8 orders the results by the float8 field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByInt4

func ByInt4(opts ...sql.OrderTermOption) OrderOption

ByInt4 orders the results by the int4 field.

func ByInt8

func ByInt8(opts ...sql.OrderTermOption) OrderOption

ByInt8 orders the results by the int8 field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByTestBs

func ByTestBs(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByTestBs orders the results by test_bs terms.

func ByTestBsCount

func ByTestBsCount(opts ...sql.OrderTermOption) OrderOption

ByTestBsCount orders the results by test_bs count.

func ByText

func ByText(opts ...sql.OrderTermOption) OrderOption

ByText orders the results by the text field.

func ByTime

func ByTime(opts ...sql.OrderTermOption) OrderOption

ByTime orders the results by the time field.

Jump to