testb

package
v0.0.0-...-1e4cd2d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the testb type in the database.
	Label = "testb"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldAID holds the string denoting the a_id field in the database.
	FieldAID = "a_id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldInt4 holds the string denoting the int4 field in the database.
	FieldInt4 = "int4"
	// FieldInt8 holds the string denoting the int8 field in the database.
	FieldInt8 = "int8"
	// FieldFloat4 holds the string denoting the float4 field in the database.
	FieldFloat4 = "float4"
	// FieldFloat8 holds the string denoting the float8 field in the database.
	FieldFloat8 = "float8"
	// FieldBool holds the string denoting the bool field in the database.
	FieldBool = "bool"
	// FieldText holds the string denoting the text field in the database.
	FieldText = "text"
	// FieldTime holds the string denoting the time field in the database.
	FieldTime = "time"
	// EdgeTestA holds the string denoting the test_a edge name in mutations.
	EdgeTestA = "test_a"
	// EdgeTestCs holds the string denoting the test_cs edge name in mutations.
	EdgeTestCs = "test_cs"
	// Table holds the table name of the testb in the database.
	Table = "test_b"
	// TestATable is the table that holds the test_a relation/edge.
	TestATable = "test_b"
	// TestAInverseTable is the table name for the TestA entity.
	// It exists in this package in order to avoid circular dependency with the "testa" package.
	TestAInverseTable = "test_a"
	// TestAColumn is the table column denoting the test_a relation/edge.
	TestAColumn = "a_id"
	// TestCsTable is the table that holds the test_cs relation/edge.
	TestCsTable = "test_c"
	// TestCsInverseTable is the table name for the TestC entity.
	// It exists in this package in order to avoid circular dependency with the "testc" package.
	TestCsInverseTable = "test_c"
	// TestCsColumn is the table column denoting the test_cs relation/edge.
	TestCsColumn = "b_id"
)

Variables

Columns holds all SQL columns for testb fields.

Functions

func AID

func AID(v int) predicate.TestB

AID applies equality check predicate on the "a_id" field. It's identical to AIDEQ.

func AIDEQ

func AIDEQ(v int) predicate.TestB

AIDEQ applies the EQ predicate on the "a_id" field.

func AIDIn

func AIDIn(vs ...int) predicate.TestB

AIDIn applies the In predicate on the "a_id" field.

func AIDIsNil

func AIDIsNil() predicate.TestB

AIDIsNil applies the IsNil predicate on the "a_id" field.

func AIDNEQ

func AIDNEQ(v int) predicate.TestB

AIDNEQ applies the NEQ predicate on the "a_id" field.

func AIDNotIn

func AIDNotIn(vs ...int) predicate.TestB

AIDNotIn applies the NotIn predicate on the "a_id" field.

func AIDNotNil

func AIDNotNil() predicate.TestB

AIDNotNil applies the NotNil predicate on the "a_id" field.

func And

func And(predicates ...predicate.TestB) predicate.TestB

And groups predicates with the AND operator between them.

func Bool

func Bool(v bool) predicate.TestB

Bool applies equality check predicate on the "bool" field. It's identical to BoolEQ.

func BoolEQ

func BoolEQ(v bool) predicate.TestB

BoolEQ applies the EQ predicate on the "bool" field.

func BoolNEQ

func BoolNEQ(v bool) predicate.TestB

BoolNEQ applies the NEQ predicate on the "bool" field.

func Float4

func Float4(v float32) predicate.TestB

Float4 applies equality check predicate on the "float4" field. It's identical to Float4EQ.

func Float4EQ

func Float4EQ(v float32) predicate.TestB

Float4EQ applies the EQ predicate on the "float4" field.

func Float4GT

func Float4GT(v float32) predicate.TestB

Float4GT applies the GT predicate on the "float4" field.

func Float4GTE

func Float4GTE(v float32) predicate.TestB

Float4GTE applies the GTE predicate on the "float4" field.

func Float4In

func Float4In(vs ...float32) predicate.TestB

Float4In applies the In predicate on the "float4" field.

func Float4LT

func Float4LT(v float32) predicate.TestB

Float4LT applies the LT predicate on the "float4" field.

func Float4LTE

func Float4LTE(v float32) predicate.TestB

Float4LTE applies the LTE predicate on the "float4" field.

func Float4NEQ

func Float4NEQ(v float32) predicate.TestB

Float4NEQ applies the NEQ predicate on the "float4" field.

func Float4NotIn

func Float4NotIn(vs ...float32) predicate.TestB

Float4NotIn applies the NotIn predicate on the "float4" field.

func Float8

func Float8(v float64) predicate.TestB

Float8 applies equality check predicate on the "float8" field. It's identical to Float8EQ.

func Float8EQ

func Float8EQ(v float64) predicate.TestB

Float8EQ applies the EQ predicate on the "float8" field.

func Float8GT

func Float8GT(v float64) predicate.TestB

Float8GT applies the GT predicate on the "float8" field.

func Float8GTE

func Float8GTE(v float64) predicate.TestB

Float8GTE applies the GTE predicate on the "float8" field.

func Float8In

func Float8In(vs ...float64) predicate.TestB

Float8In applies the In predicate on the "float8" field.

func Float8LT

func Float8LT(v float64) predicate.TestB

Float8LT applies the LT predicate on the "float8" field.

func Float8LTE

func Float8LTE(v float64) predicate.TestB

Float8LTE applies the LTE predicate on the "float8" field.

func Float8NEQ

func Float8NEQ(v float64) predicate.TestB

Float8NEQ applies the NEQ predicate on the "float8" field.

func Float8NotIn

func Float8NotIn(vs ...float64) predicate.TestB

Float8NotIn applies the NotIn predicate on the "float8" field.

func HasTestA

func HasTestA() predicate.TestB

HasTestA applies the HasEdge predicate on the "test_a" edge.

func HasTestAWith

func HasTestAWith(preds ...predicate.TestA) predicate.TestB

HasTestAWith applies the HasEdge predicate on the "test_a" edge with a given conditions (other predicates).

func HasTestCs

func HasTestCs() predicate.TestB

HasTestCs applies the HasEdge predicate on the "test_cs" edge.

func HasTestCsWith

func HasTestCsWith(preds ...predicate.TestC) predicate.TestB

HasTestCsWith applies the HasEdge predicate on the "test_cs" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.TestB

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.TestB

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.TestB

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.TestB

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.TestB

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.TestB

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.TestB

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.TestB

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.TestB

IDNotIn applies the NotIn predicate on the ID field.

func Int4

func Int4(v int32) predicate.TestB

Int4 applies equality check predicate on the "int4" field. It's identical to Int4EQ.

func Int4EQ

func Int4EQ(v int32) predicate.TestB

Int4EQ applies the EQ predicate on the "int4" field.

func Int4GT

func Int4GT(v int32) predicate.TestB

Int4GT applies the GT predicate on the "int4" field.

func Int4GTE

func Int4GTE(v int32) predicate.TestB

Int4GTE applies the GTE predicate on the "int4" field.

func Int4In

func Int4In(vs ...int32) predicate.TestB

Int4In applies the In predicate on the "int4" field.

func Int4LT

func Int4LT(v int32) predicate.TestB

Int4LT applies the LT predicate on the "int4" field.

func Int4LTE

func Int4LTE(v int32) predicate.TestB

Int4LTE applies the LTE predicate on the "int4" field.

func Int4NEQ

func Int4NEQ(v int32) predicate.TestB

Int4NEQ applies the NEQ predicate on the "int4" field.

func Int4NotIn

func Int4NotIn(vs ...int32) predicate.TestB

Int4NotIn applies the NotIn predicate on the "int4" field.

func Int8

func Int8(v int) predicate.TestB

Int8 applies equality check predicate on the "int8" field. It's identical to Int8EQ.

func Int8EQ

func Int8EQ(v int) predicate.TestB

Int8EQ applies the EQ predicate on the "int8" field.

func Int8GT

func Int8GT(v int) predicate.TestB

Int8GT applies the GT predicate on the "int8" field.

func Int8GTE

func Int8GTE(v int) predicate.TestB

Int8GTE applies the GTE predicate on the "int8" field.

func Int8In

func Int8In(vs ...int) predicate.TestB

Int8In applies the In predicate on the "int8" field.

func Int8LT

func Int8LT(v int) predicate.TestB

Int8LT applies the LT predicate on the "int8" field.

func Int8LTE

func Int8LTE(v int) predicate.TestB

Int8LTE applies the LTE predicate on the "int8" field.

func Int8NEQ

func Int8NEQ(v int) predicate.TestB

Int8NEQ applies the NEQ predicate on the "int8" field.

func Int8NotIn

func Int8NotIn(vs ...int) predicate.TestB

Int8NotIn applies the NotIn predicate on the "int8" field.

func Name

func Name(v string) predicate.TestB

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.TestB

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.TestB

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.TestB

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.TestB

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.TestB

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.TestB

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.TestB

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.TestB

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.TestB

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.TestB

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.TestB

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.TestB

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.TestB

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.TestB) predicate.TestB

Or groups predicates with the OR operator between them.

func Text

func Text(v string) predicate.TestB

Text applies equality check predicate on the "text" field. It's identical to TextEQ.

func TextContains

func TextContains(v string) predicate.TestB

TextContains applies the Contains predicate on the "text" field.

func TextContainsFold

func TextContainsFold(v string) predicate.TestB

TextContainsFold applies the ContainsFold predicate on the "text" field.

func TextEQ

func TextEQ(v string) predicate.TestB

TextEQ applies the EQ predicate on the "text" field.

func TextEqualFold

func TextEqualFold(v string) predicate.TestB

TextEqualFold applies the EqualFold predicate on the "text" field.

func TextGT

func TextGT(v string) predicate.TestB

TextGT applies the GT predicate on the "text" field.

func TextGTE

func TextGTE(v string) predicate.TestB

TextGTE applies the GTE predicate on the "text" field.

func TextHasPrefix

func TextHasPrefix(v string) predicate.TestB

TextHasPrefix applies the HasPrefix predicate on the "text" field.

func TextHasSuffix

func TextHasSuffix(v string) predicate.TestB

TextHasSuffix applies the HasSuffix predicate on the "text" field.

func TextIn

func TextIn(vs ...string) predicate.TestB

TextIn applies the In predicate on the "text" field.

func TextLT

func TextLT(v string) predicate.TestB

TextLT applies the LT predicate on the "text" field.

func TextLTE

func TextLTE(v string) predicate.TestB

TextLTE applies the LTE predicate on the "text" field.

func TextNEQ

func TextNEQ(v string) predicate.TestB

TextNEQ applies the NEQ predicate on the "text" field.

func TextNotIn

func TextNotIn(vs ...string) predicate.TestB

TextNotIn applies the NotIn predicate on the "text" field.

func Time

func Time(v time.Time) predicate.TestB

Time applies equality check predicate on the "time" field. It's identical to TimeEQ.

func TimeEQ

func TimeEQ(v time.Time) predicate.TestB

TimeEQ applies the EQ predicate on the "time" field.

func TimeGT

func TimeGT(v time.Time) predicate.TestB

TimeGT applies the GT predicate on the "time" field.

func TimeGTE

func TimeGTE(v time.Time) predicate.TestB

TimeGTE applies the GTE predicate on the "time" field.

func TimeIn

func TimeIn(vs ...time.Time) predicate.TestB

TimeIn applies the In predicate on the "time" field.

func TimeLT

func TimeLT(v time.Time) predicate.TestB

TimeLT applies the LT predicate on the "time" field.

func TimeLTE

func TimeLTE(v time.Time) predicate.TestB

TimeLTE applies the LTE predicate on the "time" field.

func TimeNEQ

func TimeNEQ(v time.Time) predicate.TestB

TimeNEQ applies the NEQ predicate on the "time" field.

func TimeNotIn

func TimeNotIn(vs ...time.Time) predicate.TestB

TimeNotIn applies the NotIn predicate on the "time" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the TestB queries.

func ByAID

func ByAID(opts ...sql.OrderTermOption) OrderOption

ByAID orders the results by the a_id field.

func ByBool

func ByBool(opts ...sql.OrderTermOption) OrderOption

ByBool orders the results by the bool field.

func ByFloat4

func ByFloat4(opts ...sql.OrderTermOption) OrderOption

ByFloat4 orders the results by the float4 field.

func ByFloat8

func ByFloat8(opts ...sql.OrderTermOption) OrderOption

ByFloat8 orders the results by the float8 field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByInt4

func ByInt4(opts ...sql.OrderTermOption) OrderOption

ByInt4 orders the results by the int4 field.

func ByInt8

func ByInt8(opts ...sql.OrderTermOption) OrderOption

ByInt8 orders the results by the int8 field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByTestAField

func ByTestAField(field string, opts ...sql.OrderTermOption) OrderOption

ByTestAField orders the results by test_a field.

func ByTestCs

func ByTestCs(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByTestCs orders the results by test_cs terms.

func ByTestCsCount

func ByTestCsCount(opts ...sql.OrderTermOption) OrderOption

ByTestCsCount orders the results by test_cs count.

func ByText

func ByText(opts ...sql.OrderTermOption) OrderOption

ByText orders the results by the text field.

func ByTime

func ByTime(opts ...sql.OrderTermOption) OrderOption

ByTime orders the results by the time field.

Jump to